Crate lightyear_steam

Crate lightyear_steam 

Lightyear Steam

This crate provides an integration layer for using Steam’s networking sockets (specifically steamworks::networking_sockets) as a transport for Lightyear.

It handles the setup of Steam P2P connections and wraps them in a way that can be used by Lightyear’s Link component. This allows Lightyear to send and receive messages over the Steam network infrastructure.

Note: This crate requires the steamworks crate and a running Steam client.

Modules

clientclient
prelude
serverserver and non-target_family=wasm

Enums

SteamError

Traits

SteamAppExt